@@ -405,11 +405,7 @@ handle_config(myproxy_server_context_t *server_context)
     }
 
 #ifdef HAVE_GLOBUS_USAGE
-        if (myproxy_usage_stats_init(server_context) != GLOBUS_SUCCESS)
-        {
-            myproxy_log("Error initializing one or more Usage Stat target(s)!"
-				" But continuing ...");
-        }
+    myproxy_usage_stats_init(server_context);
 #endif
     }
 
@@ -521,7 +517,7 @@ handle_client(myproxy_socket_attrs_t *attrs,
                     client_request->command_type);
         respond_with_error_and_die(attrs, "UNKNOWN command in request.\n", context);
     }
-    if (client_request->username) {
+    if (client_request->username && client_request->username[0]) {
         myproxy_log("Received %s request for username %s",
                     command_name, client_request->username);
     } else {
