@@ -800,40 +800,41 @@ regex_compare(const char *regex,
 	{
 
 	case '*':
-	    /* '*' turns into '.*' */
-	    *bufp++ = '.';
+	    /* unescaped '*' turns into '.*' */
+	    if (!escaped)
+		*bufp++ = '.';
 	    *bufp++ = '*';
+	    escaped = 0;
 	    break;
 
 	case '?':
-	    /* '?' turns into '.' */
-	    *bufp++ = '.';
-	    break;
-
-	   /* '\' might be escaping the succeeding meta-character */
-	case '\\':
-	    *bufp++ = *regex;
-	    escaped = !escaped;
-	    break;
-
-	   /* Need to escape other metacharacters if not already done
-	      manually by the user */
-	case '.':
-	case '[':
-	case ']':
-	case '(':
-	case ')':
-	case '{':
-	case '}':
-	case '^':
-	case '$':
-	case '+':
-	case '|':
+	    /* unescaped '?' turns into '.' */
 	    if (!escaped)
-	        *bufp++ = '\\';
-	/* fallthru to default */
+		*bufp++ = '.';
+	    else
+		*bufp++ = '?';
+	    escaped = 0;
+	    break;
+
+	case '\\':
+	    /* '\' escapes the succeeding character */
+	    if (!escaped)
+		escaped = 1;
+	    else {
+		*bufp++ = '\\';
+		escaped = 0;
+	    }
+	    break;
+
+	case '.':
+	    /* '.' needs to be taken literally */
+	    escaped = 1;
+
+	    /* fallthru to default */
 
 	default:
+	    if (escaped)
+		*bufp++ = '\\';
 	    *bufp++ = *regex;
 	    escaped = 0;
 	}
@@ -1223,8 +1224,8 @@ check_config(myproxy_server_context_t *context)
 	    rval = -1;
 	}
 	if (context->cert_dir == NULL)
-            myproxy_log("WARNING: cert_dir not specified in config file. "
-                        "No trustroots can be returned to clients!");
+            myproxy_log("cert_dir not specified in config file, so "
+                        "no trustroots will be provided to clients");
         else if (!myproxy_check_cert_dir(context->cert_dir)) {
 	    verror_put_string("The trustroots directory %s has failed sanity"
                         " checks.", context->cert_dir);
